@@ -15,7 +15,7 @@ def get(url, payload=None):
     """
     response = json.loads(requests.post(url, json=payload).text)
     if "errors" in response.keys():
-        raise InvalidRequest(response, payload)
+        raise InvalidRequest(url, response, payload)
     return response
 
 
